@@ -100,10 +100,13 @@ class Speakeasy(object):
 
         elif metric_type == 'PERCENTILE' or metric_type == 'HISTOGRAM':
             # Kill off the HISTOGRAM type!!
-            self.metrics[app_name]['PERCENTILE'][metric_name].append(value)
+            metric_type = 'PERCENTILE'
+            self.metrics[app_name][metric_type][metric_name].append(value)
             # Publish the current running percentiles
             for p in self.percentiles:
-                pub_metrics.append((self.hostname, app, '{0}{1}_percentile'.format(m, int(p*100)), 'PERCENTILE', utils.percentile(vals, p), time.time()))
+                pub_metrics.append((self.hostname, app_name, '{0}{1}_percentile'.format(metric_name, int(p*100)), 'GAUGE', utils.percentile(self.metrics[app_name][metric_type][metric_name], p), time.time()))
+            avg = sum(self.metrics[app_name][metric_type][metric_name])/len(self.metrics[app_name][metric_type][metric_name])
+            pub_metrics.append((self.hostname, app_name, '{0}average'.format(metric_name), metric_type, avg, time.time()))
 
         elif metric_type == 'COUNTER':
             self.metrics[app_name][metric_type][metric_name] += value
@@ -207,6 +210,7 @@ class Speakeasy(object):
                 for p in self.percentiles:
                     # Assume the metric name has a trailing separator to append the percentile to
                     metrics.append((app, '{0}{1}_percentile'.format(m, int(p*100)), utils.percentile(vals, p), 'GAUGE', time.time()))
+                metrics.append((app, '{0}average'.format(m), sum(vals) / float(len(vals)), 'GAUGE', time.time()))
 
         return metrics
 
@@ -214,11 +218,13 @@ class Speakeasy(object):
         """ Reset metrics for next interval """
         for app in self.metrics:
             self.metrics[app]['GAUGE'] = collections.defaultdict(list)
+            self.metrics[app]['PERCENTILE'] = collections.defaultdict(list)
 
     def init_app_metrics(self, app):
         """ Setup initial metric structure for new app """
         if app not in self.metrics:
-            self.metrics[app] = {'GAUGE': collections.defaultdict(list), 'COUNTER': collections.defaultdict(int)}
+            self.metrics[app] = {'GAUGE': collections.defaultdict(list), 'COUNTER': collections.defaultdict(int),
+                    'PERCENTILE': collections.defaultdict(list)}
 
     def start(self):
         self.__start()
